# -*- coding: utf-8 -*-

from autocomplete_light.widgets import ChoiceWidget, MultipleChoiceWidget
from django.contrib import admin
from django import http
from django.views import generic
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext as ugt
from django.utils.formats import date_format
from django import forms
from django.conf import settings
from django.core.urlresolvers import reverse
from django.core.files.base import ContentFile
import autocomplete_light

from jmb.jadmin import JumboModelAdmin
from jmb.jadmin import AjaxInline, register_inline
from jmb.project.models import Project
from jmb.core.forms.models import AdminModelForm
from jmb.core.utils.ooutils import OOUtils

from . import models, views, forms as admin_forms
from jmb.organization.models import Contact, Organization


DocumentAdminAutocompl = autocomplete_light.modelform_factory(
    models.Document, exclude=[],
)
class DocumentAjaxInline(AjaxInline):
    model = models.Document
    width = 1100
    height = 650
    fk_name = 'organization'
    list_display = ('title', 'file', 'category', 'tipology')


class DocumentAdminForm(AdminModelForm):
    autocomplete_names = {
        'notify_group': 'group',
        #'projects': 'DocumentProjectAutocomplete',
    }
    class Media:
        js = ('document/js/document_form.js',)
        # widgets = {
        #     'projects': autocomplete_light.MultipleChoiceWidget('DocumentProjectAutocomplete')
        # }

    def __init__(self, *args, **kwargs):
        super(DocumentAdminForm, self).__init__(*args, **kwargs)
        self.fields['projects'] = forms.ModelMultipleChoiceField(
            queryset=models.DocumentProject.objects.all(), required=False,
            widget=autocomplete_light.MultipleChoiceWidget('DocumentProjectAutocomplete')
        )



class DocumentAdmin(JumboModelAdmin):

    form = DocumentAdminForm

    action_form = admin_forms.DocumentActionForm

    fieldsets = (
        (_('Document'), {'fields': (
            ('file', 'get_thumb_html'),
            ('title', 'status'),
            ('tipology', 'direction'),
            ('category', 'support'),
            ('keywords', 'other_category'),
        )}),
        (_('Filing'), {'fields': (
            ('organization', 'person',),
            ('projects',),
            ('reception_date', 'date_doc'),
            ('number', 'protocol_number'),
            ('pages',),
            #            ('assigned_by', 'assigned_to',),
            #('notify_group',),
            #            ('downloadable_by'),
            'note'
        )}),
    )

    filter_horizontal = ('projects', 'notify_group')
    list_display = (
        'get_thumb_html', 'get_edit_icon_iframe',
        'get_detail', 'category', 'tipology',
        'get_year', 'title', 'get_groups', 'get_doc_number',
        'get_prot_number', 'get_creator',
        'get_linked_documents',
        'get_delete_icon', 'status', 'support', 'get_working',
    )
    list_editable = ('tipology', 'category', 'status', 'title')
    list_filter = ('tipology', 'category')
    list_display_csv = ('get_short_status', 'title', 'organization', 'person', 'file', 'number')
    readonly_fields = ('get_thumb_html',)
    detail_display = (('title', ('date_create', 'date_last_modify',),))
    default_group_by = 'category'
    ordering = ('-status',)
    save_as = True
    save_on_top = True
    actions = ['join', 'split', 'filing']
    date_hierarchy = 'date_doc'

    advanced_search_fields = (
        ('status', 'projects', 'keywords',),
        ('title__icontains', 'organization__code__icontains', 'organization__name__icontains'),
        ('person__last_name__icontains', 'person__first_name__icontains'),
        ('category__in', 'tipology__in', 'tipology__isnull'),
        ('date_create__range', 'date_create__gte', 'support', ),
        ('date_doc__year', 'date_doc__range', ),
        ('date_doc__gte', 'date_doc__lte'),
        ('number__gte', 'number__lte'),
        ('protocol_number__gte', 'protocol_number__lte'),
    )
    tabs = (
        (_('Document'), {'items': [_('Document')]}),
        (_('Filing'), {'items': [_('Filing')]}),
    )

    def get_filterset_class(self, request):
        DocFilterset = super(DocumentAdmin, self).get_filterset_class(request)

        class MyFilterset(DocFilterset):
            def __init__(self, *args, **kw):
                super(MyFilterset, self).__init__(*args, **kw)
                widget_with_autocompl = autocomplete_light.ChoiceWidget(
                    'DocumentProjectAutocomplete')
                self.form.fields['projects'].widget = widget_with_autocompl
        return MyFilterset

    def filing(self, request, queryset):
        form = self.get_action_form_instance(request)
        kw = {}
        for field_name in form.fields_map['filing']:
            if field_name in form.cleaned_data:
                kw[field_name] = form.cleaned_data[field_name]

        for doc in queryset:
            for key, value in kw.iteritems():
                setattr(doc, key, value)
            doc.save()

    def get_urls(self):
        from django.conf.urls import patterns, url
        urls = super(DocumentAdmin, self).get_urls()
        my_urls = patterns(
            '',
            url(r'^(?P<object_id>\d+)/file_with_label/$', self.admin_site.admin_view(
                self.download_file_with_label), name='document_document_file_with_label'),
            url(
                r'^bulk_upload/$',
                views.DocumentBulkCreateView.as_view(),
                name='document_bulk_create'
            ),
            url(
                r'^(?P<pk>\d+)/ajaxdel/$',
                views.DocumentDeleteView.as_view(),
                name='document_ajax_delete'
            ),
            url(
                r'^(?P<pk>\d+)/inline/$',
                self.get_file_inline,
                name='document_inline'
            ),
            url(
                r'^iframe_return',
                generic.TemplateView.as_view(template_name="fileupload/iframe_return.html"),
                name="iframe_return"),
        )
        return my_urls + urls

    def get_file_inline(self, request, pk):
        """Return file with 'inline' in Content-Disposition to be shown in the browser
        """
        obj = models.Document.objects.get(pk=pk)
        response = http.HttpResponse(content_type='application/pdf')
        response['Content-Disposition'] = 'inline; filename=%s.pdf' % obj.title
        with open(obj.file.path) as f:
            response.write(f.read())
        return response

    def download_file_with_label(self, request, object_id):
        # Creo al volo il file con il watermark (o label) e lo ritorno in un HttpResponse
        #
        import StringIO
        from pyPdf import PdfFileReader, PdfFileWriter
        from django.http import HttpResponse

        obj = models.Document.objects.get(id=object_id)

        # Apro il file dove deve essere appiccicato il watermark
        orig_file = PdfFileReader(obj.file)
        page1 = orig_file.getPage(0)
        watermark = PdfFileReader(obj.etichetta)

        # Appiccico il watermark nella prima pagina
        page1.mergePage(watermark.getPage(0))

        # finally, write "output" to document-output.pdf
        output_packet = StringIO.StringIO()
        output = PdfFileWriter()
        output.addPage(page1)
        for i in range(1, orig_file.getNumPages()):
            page = orig_file.getPage(i)
            output.addPage(page)
        #outputStream = file("/tmp/watermark1.pdf", "wb")
        output.write(output_packet)
        output_packet.seek(0)

        response = HttpResponse(output_packet.read())

        response['Content-Type'] = 'application/pdf'
        return response

    def create_label(self, request, queryset):
        # Action che crea un pdf solo con la label che poi verra' appiccicata
        # al file solo nel momento in cui viene richiesto il documento con la label

        o = OOUtils()
        label_created = 0

        for d in queryset:
            filename = d.file.name.split('/')[-1]
            raw_pdf = o.save_pdf(
                request, 'admin/document/document/watermark.odt', obj=d, get_raw_string=True)
            file_content = ContentFile(raw_pdf.read())
            d.etichetta.save(filename, file_content)
            label_created += 1

        if label_created == 1:
            message_bit = _("1 Document Label Created")
        else:
            message_bit = _("%(row)s Documents Label Created") % {'row': label_created}
        self.message_user(request, _("%(msg)s") % {'msg': message_bit})
    create_label.short_description = _("Create Label")

    def save_model(self, request, obj, form, change):
        super(DocumentAdmin, self).save_model(request, obj, form, change)

        # Se e' stata selezionata una categoria monitorata via mail
        # spedisco la mail ai relativi destinatari
        if 'other_category' in form.cleaned_data:
            for cat in form.cleaned_data['other_category']:
                if cat.notify_to_add_document:
                    obj.send_mail_add_document_to_category(cat, change)

    def set_as_completed(self, request, queryset):
        rows_updated = queryset.update(status='CM')
        if rows_updated == 1:
            message_bit = ugt("1 object was")
        else:
            message_bit = ugt("%(row)s objects were") % {'row': rows_updated}
        self.message_user(
            request, ugt("%(msg)s successfully setted.") % {'msg': message_bit}
        )
    set_as_completed.short_description = _("Set %(verbose_name_plural)s as completed")
    admin.site.add_action(set_as_completed)

    def set_as_to_complete(self, request, queryset):
        rows_updated = queryset.update(status='TC')
        if rows_updated == 1:
            message_bit = ugt("1 object was")
        else:
            message_bit = ugt("%(row)s objects were") % {'row': rows_updated}
        self.message_user(
            request, ugt("%(msg)s successfully setted.") % {'msg': message_bit}
        )
    set_as_to_complete.short_description = _("Set %(verbose_name_plural)s as to complete")
    admin.site.add_action(set_as_to_complete)

    def get_actions(self, request):
        actions = super(DocumentAdmin, self).get_actions(request)
        del actions['set_active']
        del actions['set_disactive']
        return actions

    def get_creator(self, obj):
        return obj.creator
    get_creator.short_description = _("Inserted By")

    def join(self, request, queryset):
        link = models.Link()
        rows_linked = 0
        for d in queryset:
            link.document = d
            link.save()
            link.id = None
            rows_linked += 1
        if rows_linked == 1:
            message_bit = _("1 Document Linked")
        else:
            message_bit = _("%(row)s Documents Linked") % {'row': rows_linked}
        self.message_user(request, _("%(msg)s") % {'msg': message_bit})
    join.short_description = _("Link Documents")

    def split(self, request, queryset):
        rows_splitted = 0
        for d in queryset:
            models.Link.objects.filter(document=d).delete()
            rows_splitted += 1
        if rows_splitted == 1:
            message_bit = _("1 Document Splitted")
        else:
            message_bit = _("%(row)s Documents Splitted") % {'row': rows_splitted}
        self.message_user(request, _("%(msg)s") % {'msg': message_bit})
    split.short_description = _("Split Documents")

    def get_year(self, obj):
        if obj.date_doc:
            return obj.date_doc.strftime("%Y")
        return ""
    get_year.short_description = _("Year")

    def get_linked_documents(self, obj):
        links = models.Link.objects.filter(document=obj)
        nlink_list = []
        for link in links:
            nlink_list.append(link.number)
        other_link_list = models.Link.objects.filter(number__in=nlink_list).exclude(document=obj)
        docs = ""
        for link in other_link_list:
            docs += "%s," % link.document.id
        if docs:
            return """
            <a
                href='/admin/document/document/?id__in={list_link}{id_obj}&search_in_all_years=on'
                title='List linked documents'
            >
                <img src="{url}admin/images/icon_addlink.gif" />
            </a>
            """.format()({
                'url': settings.MEDIA_URL,
                'list_link': docs,
                'id_obj': obj.id
            })
        return ""
    get_linked_documents.short_description = _("L")
    get_linked_documents.allow_tags = True

    def get_short_status(self, obj):
        return obj.status
    get_short_status.short_description = _("ST")
    get_short_status.admin_order_field = 'status'

    # def get_is_public(self, obj):
    #     return obj.is_public
    # get_is_public.short_description = _("P")
    # get_is_public.admin_order_field = 'is_public'
    # get_is_public.boolean = True

    def get_working(self, obj):
        return obj.working
    get_working.short_description = _("L")
    get_working.admin_order_field = 'working'
    get_working.boolean = True

    def get_doc_number(self, obj):
        return obj.number
    get_doc_number.short_description = ("Doc N.")
    get_doc_number.admin_order_field = 'number'

    def get_prot_number(self, obj):
        return obj.protocol_number
    get_prot_number.short_description = ("Prot N.")
    get_prot_number.admin_order_field = 'protocol_number'

    def get_groups(self, obj):
        g = [x.name for x in obj.notify_group.all()]
        return ', '.join(g)
    get_groups.short_description = _("Groups")

    def get_print_icon(self, obj):
        return """<a href="#" onclick="Dajaxice.document.print_document_label(Dajax.process, {'obj_id':%d});">P</a>""" % obj.id
    get_print_icon.short_description = _("Print")
    get_print_icon.allow_tags = True

    def get_detail(self, obj):
        organization = (obj.organization and obj.organization.name) or ""
        person = obj.person or ""
        projects = obj.get_string_projects()
        if organization or person:
            return "<b>{}</b><br/>{}<br/>{}".format(organization, person, projects)
        else:
            return "{}".format(projects)

    get_detail.short_description = _("Detail")
    get_detail.allow_tags = True
    get_detail.admin_order_field = 'organization__name'

    def get_date_doc(self, obj):
        return date_format(obj.date_doc.date())
    get_date_doc.short_description = _("Date")
    get_date_doc.allow_tags = True

    def get_link_file(self, obj):
        if obj.can_be_downloaded():
            return (
                '<a target="_blank" href="{url}" title="{title}">'
                '<img src="{media_url}admin/images/document.png" '
                'alt="{description}" title="%(description)s"/></a>'.format(
                    url=obj.file.url,
                    title=obj.file.name,
                    media_url=settings.MEDIA_URL,
                    description=_("Download Document")
                )
            )
        return ""
    get_link_file.short_description = _("D")
    get_link_file.allow_tags = True

    def get_link_file_with_label(self, obj):
        if obj.can_be_downloaded() and obj.etichetta:
            return (
                '<a target="_blank" href="%(url)s" title="%(title)s">'
                '<img src="%(media_url)sadmin/images/document.png" '
                'alt="%(description)s" title="%(description)s"/></a></a>'.format(
                    url=reverse('admin:document_document_file_with_label', obj.id),
                    title=_('Download Document With Label'),
                    media_url=settings.MEDIA_URL,
                    description=_("Download Document With Label"),
                )
            )
        return ""
    get_link_file_with_label.short_description = _("DL")
    get_link_file_with_label.allow_tags = True


class DocumentProjectAdminForm(AdminModelForm):
    project_ptr_id = forms.IntegerField(
        required=False,
        widget=forms.HiddenInput,
        label=""
    )

    def __init__(self, *args, **kwargs):
        super(DocumentProjectAdminForm, self).__init__(*args, **kwargs)

        organization_id = self.get_object_id('organization')
        # project_id = self.get_object_id('project')

        organization_qs = Organization.customers_owners

        # imposta i queryset vuoti
        # project_qs = TicketProject.objects.none()
        manager_qs = Contact.objects.all()
        staff_qs = Contact.objects.all()
        # customer_qs = Contact.objects.none()

        if organization_id:
            manager_qs = Contact.owners
            staff_qs = Contact.workers
            # customer_qs = Contact.objects.filter(organization__id=organization_id)

        self.fields['organization'] = forms.ModelChoiceField(
            queryset=organization_qs,
            widget=ChoiceWidget('CustomerOwnerOrganization')
        )
        self.fields['managers'] = forms.ModelMultipleChoiceField(
            widget=MultipleChoiceWidget('OwnerContact'),
            queryset=manager_qs
        )
        self.fields['staff'] = forms.ModelMultipleChoiceField(
            widget=MultipleChoiceWidget('WorkerContact'),
            queryset=staff_qs
        )

    class Meta:
        model = models.DocumentProject
        fields = ('managers', 'staff', 'project_ptr')
        widgets = {

        }

    def save(self, *args, **kwargs):
        ## commit=False, default aggiunge save_m2m()
        ## che viene chiamata in seguito da django
        dp = super(DocumentProjectAdminForm, self).save(commit=kwargs['commit'])
        dp.save()  # necessaria per creare anche Project
        ## sto aggiungendo partendo da un progetto esistente
        if self.cleaned_data['project_ptr_id']:
            project_id = self.cleaned_data['project_ptr_id']
            dp.project_ptr_id = project_id
            ## Trovo il Progetto da cui si estende il DocumentProject
            project = Project.objects.get(id=project_id)
            dp.project_ptr = project
        ## sto modificando un TicketProject esistente
        else:
            project = dp.project_ptr

        dp.date_create = project.date_create
        dp.creator = project.creator
        dp.status = project.status
        # dp.o_number = project.o_number
        # dp.c_number = project.c_number
        # dp.o_date = project.o_date
        # dp.c_date = project.c_date
        dp.accepted = project.accepted
        dp.name = project.name
        dp.organization = project.organization
        dp.description = project.description
        dp.date_start = project.date_start
        dp.date_end = project.date_end
#        import ipdb; ipdb.set_trace()
        dp.save()
        return dp

class DocumentProjectAdmin(JumboModelAdmin):
    list_per_page = 30
    form = DocumentProjectAdminForm
    fieldsets = (
        (_('general admin'), {'fields': (
            ('name', 'status', ),
            ('organization', ),
            'description',
            ('date_start', 'date_end'),
        )}),
        (_('Gestione'), {
            'fields': ('managers', 'staff', 'project_ptr_id')
        }),



    )
    list_display = ('get_edit_icon', 'get_delete_icon', 'status', 'name', 'organization',
                    'get_date_start', 'get_date_end',
                    'get_string_managers', 'get_string_staff')
    list_display_csv = ('status', 'name', 'organization', 'get_date_start',
                        'get_date_end', 'get_string_managers', 'get_string_staff')
    list_display_links = ['name']
    detail_display = (
        'status', 'organization', 'name', 'description',
        ('date_start', 'date_end'), ('managers', 'staff')
    )
    filter_horizontal = ('managers', 'staff')
    save_as = True
    save_on_top = True

    def get_date_start(self, obj):
        return date_format(obj.date_start)
    get_date_start.short_description = _('Date')
    get_date_start.admin_order_field = 'date_start'

    def get_date_end(self, obj):
        return obj.date_end and date_format(obj.date_end) or None
    get_date_end.short_description = _('Date')
    get_date_end.admin_order_field = 'date_end'


class CategoryAdmin(JumboModelAdmin):

    class Media:
        css = {"all": ("document/css/admin_document.css",)}

    #search_form = CategorySearchForm
    list_per_page = 30
    fieldsets = (
        (_('General Information'), {
            'fields': ('status', 'code', 'name', 'email', 'note',
                       'notify_to_add_document', 'notify_email')
        }),
    )
    search_fields = ('status', 'code', 'email', 'name')
    list_display = ('status', 'code', 'name', 'note', 'email', 'get_default_groups',
                    'get_default_users', 'get_edit_icon', 'get_delete_icon')
    list_display_csv = ('status', 'code', 'name', 'email')
    detail_display = ('status', 'code', 'name', 'email')
    default_group_by = 'status'
    save_as = True
    save_on_top = True
    actions = None  # ['set_active', 'set_disactive']

    def get_default_groups(self, obj):
        return ','.join([x.name for x in obj.get_default_groups()])
    get_default_groups.short_description = _('Default Groups')

    def get_default_users(self, obj):
        return ','.join([x.user.username for x in obj.get_default_users()])
    get_default_users.short_description = _('Default Users')


class OtherCategoryAdmin(JumboModelAdmin):

    class Media:
        css = {"all": ("document/css/admin_document.css",)}

    list_per_page = 30
    fieldsets = (
        (_('General Information'), {
            'fields': ('status', 'code', 'name', 'email', 'note',
                       'notify_to_add_document', 'notify_email')
        }),
    )
    search_fields = ('status', 'code', 'email', 'name')
    list_display = ('status', 'code', 'name', 'note', 'email', 'get_edit_icon', 'get_delete_icon')
    list_display_csv = ('status', 'code', 'name', 'email')
    #list_display_links = ['name']
    detail_display = ('status', 'code', 'name', 'email')
    default_group_by = 'status'
    save_as = True
    save_on_top = True
    actions = None  # ['set_active', 'set_disactive']


class DefaultAdmin(JumboModelAdmin):

    class Media:
        css = {"all": ("document/css/admin_document.css",)}

    list_per_page = 30
    fieldsets = (
        (_('User Info'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('General Information'), {
            'fields': ('category', 'users', 'groups')
        }),
    )
    list_display = ('category', 'get_string_users', 'get_string_groups')
    list_display_csv = ('category', 'get_users', 'get_groups')
    list_display_links = ['category']
    ordering = ['category']
    save_as = True
    save_on_top = True

admin.site.register(models.Tipology)
admin.site.register(models.Category, CategoryAdmin)
admin.site.register(models.OtherCategory, OtherCategoryAdmin)
admin.site.register(models.Document, DocumentAdmin)
admin.site.register(models.DocumentProject, DocumentProjectAdmin)
admin.site.register(models.Default, DefaultAdmin)
#admin.site.register(models.DocumentUser, DocumentUserAdmin)
register_inline(DocumentAjaxInline)
