# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings
import jmb.document.models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('project', '__first__'),
        ('organization', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(unique=True, max_length=15, verbose_name='Code', db_index=True)),
                ('name', models.CharField(unique=True, max_length=30, verbose_name='Name', db_index=True)),
                ('email', models.EmailField(help_text='Used for Scan2Email', unique=True, max_length=75, verbose_name='Email')),
                ('note', models.TextField(null=True, verbose_name='Note', blank=True)),
                ('notify_to_add_document', models.BooleanField(default=False, verbose_name='Notify To Add Document')),
                ('notify_email', models.TextField(null=True, verbose_name='Notify Email', blank=True)),
                ('creator', models.ForeignKey(related_name='document_category_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='document_category_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Category',
                'verbose_name_plural': 'Categories',
                'permissions': (('view_category', 'Can view document category'), ('list_all_categories', 'Can list all document categories')),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='CategoryPermission',
            fields=[
                ('permission_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='auth.Permission')),
                ('model_id', models.PositiveIntegerField(verbose_name='Model ID', db_index=True)),
            ],
            options={
            },
            bases=('auth.permission',),
        ),
        migrations.CreateModel(
            name='Default',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('category', models.ForeignKey(related_name='document_defaults', verbose_name='Category', to='document.Category', unique=True)),
                ('creator', models.ForeignKey(related_name='document_default_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('groups', models.ManyToManyField(related_name='document_defaults', to='auth.Group', blank=True, null=True, verbose_name='Groups', db_index=True)),
                ('last_modifier', models.ForeignKey(related_name='document_default_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'Default',
                'verbose_name_plural': 'Defaults',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Document',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('status', models.CharField(db_index=True, max_length=2, verbose_name='Status', choices=[(b'CM', 'COMPLETED'), (b'TC', 'TO COMPLETE')])),
                ('date_doc', models.DateTimeField(db_index=True, null=True, verbose_name='Document Date and Time', blank=True)),
                ('number', models.CharField(db_column=b'dnumber', max_length=20, blank=True, null=True, verbose_name='Document Number', db_index=True)),
                ('working', models.BooleanField(default=False, db_index=True, verbose_name='Working')),
                ('reception_date', models.DateTimeField(verbose_name='Reception Date', db_index=True)),
                ('protocol_number', models.IntegerField(db_index=True, null=True, verbose_name='Protocol Number', blank=True)),
                ('title', models.CharField(max_length=100, verbose_name='Title', db_index=True)),
                ('keywords', models.CharField(db_index=True, max_length=200, null=True, verbose_name='Keywords', blank=True)),
                ('pages', models.PositiveSmallIntegerField(max_length=3, null=True, verbose_name='Pag.', blank=True)),
                ('support', models.CharField(db_index=True, max_length=1, verbose_name='Support', choices=[(b'S', b'SCANNER'), (b'M', b'MAIL'), (b'F', b'FAX'), (b'W', b'WEB')])),
                ('file', models.FileField(upload_to=jmb.document.models.get_document_upload_to, verbose_name='File PDF')),
                ('etichetta', models.FileField(upload_to=jmb.document.models.get_document_etichetta_upload_to, null=True, verbose_name='Etichetta PDF', blank=True)),
                ('note', models.TextField(null=True, verbose_name='Note', blank=True)),
                ('is_public', models.BooleanField(default=False)),
                ('direction', models.CharField(choices=[(b'I', b'IN'), (b'O', b'OUT')], max_length=1, blank=True, null=True, verbose_name='Direction', db_index=True)),
            ],
            options={
                'verbose_name': 'Document',
                'verbose_name_plural': 'Documents',
                'permissions': (('view_document', 'Can view document'), ('list_all_documents', 'Can list all documents'), ('list_group_documents', 'Can list group documents'), ('list_organization_documents', 'Can list organization documents'), ('list_own_documents', 'Can list own documents'), ('add_all_documents', 'Can add all documents'), ('change_all_documents', 'Can change all documents'), ('delete_all_documents', 'Can delete all documents'), ('download_all_documents', 'Can download all documents')),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DocumentProject',
            fields=[
                ('project_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='project.Project')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Document Project',
                'verbose_name_plural': 'Document Projects',
                'permissions': (('view_documentproject', 'Can view document project'), ('list_all_documentprojects', 'Can list all document projects')),
            },
            bases=('project.project',),
        ),
        migrations.CreateModel(
            name='DocumentUser',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('enabled', models.BooleanField(default=False, db_index=True, verbose_name='Enabled')),
                ('user', models.OneToOneField(related_name='document_user', verbose_name='User', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('user__contact__organization', 'user__contact__last_name', 'user__contact__first_name', 'user__username'),
                'verbose_name': 'Document User',
                'verbose_name_plural': 'Document Users',
                'permissions': (('view_documentuser', 'Can view documentuser'), ('list_all_documentusers', 'Can list all documentusers')),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Link',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('number', models.IntegerField(verbose_name='Link Number', db_column=b'lnumber', db_index=True)),
                ('creator', models.ForeignKey(related_name='document_link_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('document', models.ForeignKey(related_name='links', verbose_name='Document', to='document.Document')),
                ('last_modifier', models.ForeignKey(related_name='document_link_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'Document Link',
                'verbose_name_plural': 'Document Links',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='OtherCategory',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(unique=True, max_length=15, verbose_name='Code', db_index=True)),
                ('name', models.CharField(unique=True, max_length=30, verbose_name='Name', db_index=True)),
                ('email', models.EmailField(help_text='Used for Scan2Email', unique=True, max_length=75, verbose_name='Email')),
                ('note', models.TextField(null=True, verbose_name='Note', blank=True)),
                ('notify_to_add_document', models.BooleanField(default=False, verbose_name='Notify To Add Document')),
                ('notify_email', models.TextField(null=True, verbose_name='Notify Email', blank=True)),
                ('creator', models.ForeignKey(related_name='document_othercategory_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='document_othercategory_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Other Category',
                'verbose_name_plural': 'Other Categories',
                'permissions': (('view_other_category', 'Can view document other category'), ('list_all_other_categories', 'Can list all document other categories')),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Tipology',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('name', models.CharField(max_length=50, verbose_name='Tipology', db_index=True)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Tipology',
                'verbose_name_plural': 'Tipologies',
                'permissions': (('view_tipology', 'Can view document tipology'), ('list_all_tipologies', 'Can list all document tipologies')),
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='link',
            unique_together=set([('number', 'document')]),
        ),
        migrations.AddField(
            model_name='documentproject',
            name='managers',
            field=models.ManyToManyField(related_name='managed_documentprojects', verbose_name='Managers', to='document.DocumentUser', db_index=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='documentproject',
            name='staff',
            field=models.ManyToManyField(related_name='assigned_documentprojects', verbose_name='Staff', to='document.DocumentUser', db_index=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='assigned_by',
            field=models.ForeignKey(related_name='documents_assigned_by_me', verbose_name='Assigned by', blank=True, to='document.DocumentUser', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='assigned_to',
            field=models.ForeignKey(related_name='documents_assigned_to_me', verbose_name='Assigned to', blank=True, to='document.DocumentUser', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='category',
            field=models.ForeignKey(related_name='documents', verbose_name='Category', to='document.Category'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='creator',
            field=models.ForeignKey(related_name='document_document_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='downloadable_by',
            field=models.ManyToManyField(related_name='documents', to='document.DocumentUser', blank=True, null=True, verbose_name='Downloadable By', db_index=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='last_modifier',
            field=models.ForeignKey(related_name='document_document_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='notify_group',
            field=models.ManyToManyField(related_name='documents', to='auth.Group', blank=True, null=True, verbose_name='notify_group', db_index=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='organization',
            field=models.ForeignKey(related_name='documents', verbose_name='Organization', blank=True, to='organization.Organization', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='other_category',
            field=models.ManyToManyField(related_name='documents', to='document.OtherCategory', blank=True, null=True, verbose_name='Category', db_index=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='person',
            field=models.ForeignKey(related_name='documents', verbose_name='Person', blank=True, to='organization.Contact', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='projects',
            field=models.ManyToManyField(related_name='documents', to='document.DocumentProject', blank=True, null=True, verbose_name='Projects', db_index=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='document',
            name='tipology',
            field=models.ForeignKey(related_name='documents', verbose_name='Tipology', blank=True, to='document.Tipology', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='default',
            name='users',
            field=models.ManyToManyField(related_name='document_defaults', to='document.DocumentUser', blank=True, null=True, verbose_name='Users', db_index=True),
            preserve_default=True,
        ),
    ]
