# encoding: utf-8
import re
import mimetypes

from django.core.urlresolvers import reverse  # noqa


def order_name(name):
    """order_name -- Limit a text to 20 chars length, if necessary strips the
    middle of the text and substitute it for an ellipsis.

    name -- text to be limited.

    """
    name = re.sub(r'^.*/', '', name)
    if len(name) <= 20:
        return name
    return name[:10] + "..." + name[-7:]


def serialize(instance, artist=None, file_attr='file'):
    """serialize -- Serialize a Picture instance into a dict.

    instance -- Picture instance
    file_attr -- attribute name that contains the FileField or ImageField

    """
    obj = getattr(instance, file_attr)

    return {
        'url': obj.url,
        'title': order_name(obj.name),
        'docname': instance.title,
        'type': mimetypes.guess_type(obj.path)[0] or 'image/png',
        'thumbnailUrl': instance.thumb.url if instance.thumb else "",
        'size': 1000,
        'category': unicode(instance.category),
        'deleteUrl': reverse('admin:document_ajax_delete', args=[instance.pk]),
        'deleteType': 'DELETE',
    }
