import json

from django import http
from django.views import generic
from django.core.urlresolvers import reverse
from django import http
from jmb.fileupload.response import JSONResponse, response_mimetype
from jmb.document import models

from . import forms
from .serialize import serialize


class DocumentBulkCreateView(generic.CreateView):
    model = models.Document
    form_class = forms.DocumentForm
    template_name = 'admin/document/document/document_form_multi.html'
    #template_name = 'admin/document/document/document_form_bulk.html'

    def form_valid(self, form):
        if self.request.is_ajax():
            object = form.save()
            data = {
                'files': [serialize(object,)]
            }
            response = JSONResponse(data, mimetype=response_mimetype(self.request))
            response['Content-Disposition'] = 'inline; filename=files.json'
            return response
        return super(DocumentBulkCreateView, self).form_valid(form)

    def get_success_url(self):
        if not self.request.is_ajax():
            return reverse('iframe_return')
        return super(DocumentBulkCreateView, self).get_success_url()

    def get_context_data(self, **kwargs):
        context = super(DocumentBulkCreateView, self).get_context_data(**kwargs)
        return context

    def form_invalid(self, form):
        if self.request.is_ajax():
            data = json.dumps(form.errors)
            print "THE FORM WAS INVALID", data
            return http.HttpResponse(
                content=data, status=400, content_type='application/json')
        return super(DocumentBulkCreateView, self).form_invalid(form)

class DocumentDeleteView(generic.DeleteView):

    """Used from within fileupload form.
    """
    ## Non usata ma lasciata per esempio di set categoria in template (document_form_bulk.html)
    model = models.Document

    def get_success_url(self):
        # iframe_return provided by jmb.fileupload
        if self.request.is_ajax():
            return reverse('admin:iframe_return')
        return super(DocumentDeleteView, self).get_success_url()

    def delete(self, request, *args, **kwargs):
        success_url = self.get_success_url()
        self.object = self.get_object()
        self.object.delete()

        if self.request.is_ajax():
            response = JSONResponse(True, mimetype=response_mimetype(request))
            response['Content-Disposition'] = 'inline; filename=files.json'
            return response
        return http.HttpResponseRedirect(success_url)
